==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/sv_SE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv_SE" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Välj en eller flera enheter</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Växla till fönsterläge</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Växla till helskärmsläge</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Nedräkning</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Välj en eller flera enheter</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Inspelningen är inte startad, det finns inte tillräckligt med ledigt diskutrymme.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Det lediga diskutrymmet är slut.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Gräns för ledigt dikutrymme</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Inspelningen har stoppats, det finns inte tillräckligt med ledigt diskutrymme.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Helskärm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ingen filhanterare hittades.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installera en filhanterare.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>Skrivbordsessionen är en Wayland-session</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Wayland stöds inte. En skärminspelning visar bara en svart skärm. Logga ut och starta en X11 skrivbordssession.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Källkod</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hemsida</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Översättningar</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donera</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland skrivbordssession identifierad</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Öppna fil</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vänd horisontellt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vänd vertikalt</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertera</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svartvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ta bort fönsterram</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamerainställningar</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Förstoringsglas</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedräkning</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videostorlek:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ledigt diskutrymme:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Inspelningstid:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Bildrutor</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Ljudkodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Spela inte in muspekaren</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Timma</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minut</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Starta tiduret</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stoppa inspelningen efter</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Timmar</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuter</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunder</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosökväg</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Gräns för ledigt diskutrymme</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Visa i systemfältet</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Vänta x sekunder före inspelningsstart</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Sök efter uppdateringar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tillgänglig</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Inte tillgänglig</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela upp</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mapp</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertera</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Skicka rapport</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Spela upp senaste inspelning</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Öppna mapp</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimerad när inspelning startar</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starta minimerad</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vänd horisontellt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vänd vertikalt</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svartvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ta bort fönsterram</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donera</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Återställ alla inställningar vid nästa programstart</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright och licens från bilder</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Skärminspelning</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spelare</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright och licens från bilder</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Spela upp</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Helskärm</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Föregående bildruta</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Nästa bildruta</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tyst</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Flytta menyn</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/sv_SE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv_SE">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Välj en eller flera enheter</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Växla till fönsterläge</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Växla till helskärmsläge</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Välj en eller flera enheter</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Ingen filhanterare hittades.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installera en filhanterare.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Inspelningen är inte startad, det finns inte tillräckligt med ledigt diskutrymme.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Det lediga diskutrymmet är slut.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Gräns för ledigt diskutrymme</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Inspelningen har stoppats, det finns inte tillräckligt med ledigt diskutrymme.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Helskärm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ingen filhanterare hittades.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installera en filhanterare.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Källkod</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hemsida</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Översättningar</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donera</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Välj en eller flera enheter</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Förstoringsglas</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vänd horisontellt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vänd vertikalt</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertera</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svartvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ta bort fönsterram</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamerainställningar</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Förstoringsglas</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedräkning</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videostorlek:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ledigt diskutrymme:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Inspelningstid:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Bildrutor</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Ljudkodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Spela inte in muspekaren</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Timma</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minut</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Starta tiduret</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stoppa inspelningen efter</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Timmar</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuter</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunder</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosökväg</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Gräns för ledigt diskutrymme</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Visa i systemfältet</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Vänta x sekunder före inspelningsstart</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Sök efter uppdateringar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tillgänglig</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Inte tillgänglig</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela upp</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mapp</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertera</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Skicka rapport</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Spela upp senaste inspelning</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Öppna mapp</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimerad när inspelning startar</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starta minimerad</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vänd horisontellt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vänd vertikalt</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svartvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ta bort fönsterram</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donera</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Återställ alla inställningar vid nästa programstart</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright och licens från bilder</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Skärminspelning</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spelare</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright och licens från bilder</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Spela upp</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Helskärm</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Föregående bildruta</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Nästa bildruta</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tyst</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Flytta menyn</translation>
    </message>
</context>
</TS>
